==> sfc-loader-0.7.1.tgz: package/lib/transform/script.js <==
"use strict";

var babylon = require('babylon');

var traverse = require('babel-traverse').default;

var generate = require('babel-generator').default;

var t = require('babel-types');

var babel = require('babel-core');

module.exports = function (scriptContent, declarationName, sourceFilename, rawContent) {
  var ast;
  var decleared = false;

  try {
    ast = babylon.parse(scriptContent, {
      sourceType: 'module',
      sourceFilename: sourceFilename
    });
  } catch (err) {
    console.log(scriptContent);
    throw new Error('Babylon parse error at transform script: ' + err.message);
  }

  var scopeIdentifiers = [];
  var definitions = {};
  var visitor = {
    Program: function Program(path) {
      if (path && path.scope && path.scope.bindings) {
        scopeIdentifiers = Object.keys(path.scope.bindings);
      }
    },
    ObjectMethod: function ObjectMethod(path) {
      var node = path.node;

      if (path.parent.__topMark) {
        definitions[node.key.name] = true;
      }
    },
    ObjectProperty: function ObjectProperty(path) {
      var node = path.node;

      if (path.parent.__topMark) {
        definitions[node.key.name] = true;
      }
    },
    ExportDefaultDeclaration: function ExportDefaultDeclaration(path) {
      var node = path.node;

      if (t.isObjectExpression(node.declaration)) {
        node.declaration.__topMark = true;
      }

      path.replaceWith(t.variableDeclaration('var', [// todo: feat 支持 module.exports 写法?
      t.variableDeclarator(t.identifier(declarationName), node.declaration)]));
      decleared = true;
    }
  };
  traverse(ast, visitor);
  var defaultDeclarationCode = "const ".concat(declarationName, " = {};\n");

  var _generate = generate(ast, {
    sourceMaps: true
  }, scriptContent),
      code = _generate.code,
      map = _generate.map; // 补充 source content


  for (var i = 0; i < map.sourcesContent.length; i++) {
    map.sourcesContent[i] = scriptContent; // readFileSync(resolve(map.sources[i]), 'utf-8');
  } // offset source


  var scriptIndex = rawContent.indexOf(scriptContent) || 0;
  var scriptBaseLine = rawContent.slice(0, scriptIndex).split(/\r?\n/g).length;

  function visitExitState() {
    return {
      visitor: {
        Program: function Program(path, state) {
          var scope = path.scope;

          if (!decleared) {
            path.pushContainer('body', t.variableDeclaration('var', [t.variableDeclarator(t.identifier(declarationName), t.objectExpression([]))]));
          } // 初始化 _global


          path.pushContainer('body', t.expressionStatement(t.assignmentExpression('=', t.memberExpression(t.identifier(declarationName), t.identifier('_global')), t.objectExpression([]))));
          Object.keys(scope.getAllBindings()).forEach(function (key) {
            path.pushContainer('body', t.expressionStatement(t.assignmentExpression('=', t.memberExpression(t.memberExpression(t.identifier(declarationName), t.identifier('_global')), t.stringLiteral(key), true), t.identifier(key))));
          });
        }
      }
    };
  }

  var _babel$transformFromA = babel.transformFromAst(ast, code, {
    // presets order from last to first
    presets: [require('babel-preset-env'), require('babel-preset-stage-0')],
    plugins: [visitExitState],
    inputSourceMap: map,
    sourceMaps: true
  }),
      $code = _babel$transformFromA.code,
      $map = _babel$transformFromA.map;

  var declarationCode = $code || defaultDeclarationCode;
  $map.sources[0] += '.js';
  return {
    scopeIdentifiers: scopeIdentifiers,
    definitions: definitions,
    declarationCode: declarationCode,
    sourceMap: $map
  };
};

==> sfc-loader-0.7.3.tgz: package/lib/transform/script.js <==
"use strict";

var babylon = require('babylon');

var traverse = require('babel-traverse').default;

var generate = require('babel-generator').default;

var t = require('babel-types');

var babel = require('babel-core');

module.exports = function (scriptContent, declarationName, sourceFilename, rawContent) {
  var ast;
  var decleared = false;

  try {
    ast = babylon.parse(scriptContent, {
      sourceType: 'module',
      sourceFilename: sourceFilename
    });
  } catch (err) {
    console.log(scriptContent);
    throw new Error('Babylon parse error at transform script: ' + err.message);
  }

  var scopeIdentifiers = [];
  var definitions = {};
  var visitor = {
    Program: function Program(path) {
      if (path && path.scope && path.scope.bindings) {
        scopeIdentifiers = Object.keys(path.scope.bindings);
      }
    },
    ObjectMethod: function ObjectMethod(path) {
      var node = path.node;

      if (path.parent.__topMark) {
        definitions[node.key.name] = true;
      }
    },
    ObjectProperty: function ObjectProperty(path) {
      var node = path.node;

      if (path.parent.__topMark) {
        definitions[node.key.name] = true;
      }
    },
    ExportDefaultDeclaration: function ExportDefaultDeclaration(path) {
      var node = path.node;

      if (t.isObjectExpression(node.declaration)) {
        node.declaration.__topMark = true;
      }

      path.replaceWith(t.variableDeclaration('var', [// todo: feat 支持 module.exports 写法?
      t.variableDeclarator(t.identifier(declarationName), node.declaration)]));
      decleared = true;
    }
  };
  traverse(ast, visitor);
  var defaultDeclarationCode = "const " + declarationName + " = {};\n";

  var _generate = generate(ast, {
    sourceMaps: true
  }, scriptContent),
      code = _generate.code,
      map = _generate.map; // 补充 source content


  for (var i = 0; i < map.sourcesContent.length; i++) {
    map.sourcesContent[i] = scriptContent; // readFileSync(resolve(map.sources[i]), 'utf-8');
  } // offset source


  var scriptIndex = rawContent.indexOf(scriptContent) || 0;
  var scriptBaseLine = rawContent.slice(0, scriptIndex).split(/\r?\n/g).length;

  function visitExitState() {
    return {
      visitor: {
        Program: function Program(path, state) {
          var scope = path.scope;

          if (!decleared) {
            path.pushContainer('body', t.variableDeclaration('var', [t.variableDeclarator(t.identifier(declarationName), t.objectExpression([]))]));
          } // 初始化 _global


          path.pushContainer('body', t.expressionStatement(t.assignmentExpression('=', t.memberExpression(t.identifier(declarationName), t.identifier('_global')), t.objectExpression([]))));
          Object.keys(scope.getAllBindings()).forEach(function (key) {
            path.pushContainer('body', t.expressionStatement(t.assignmentExpression('=', t.memberExpression(t.memberExpression(t.identifier(declarationName), t.identifier('_global')), t.stringLiteral(key), true), t.identifier(key))));
          });
        }
      }
    };
  }

  var _babel$transformFromA = babel.transformFromAst(ast, code, {
    // presets order from last to first
    presets: [require('babel-preset-env'), require('babel-preset-stage-0')],
    plugins: [visitExitState],
    inputSourceMap: map,
    sourceMaps: true
  }),
      $code = _babel$transformFromA.code,
      $map = _babel$transformFromA.map;

  var declarationCode = $code || defaultDeclarationCode;
  $map.sources[0] += '.js';
  return {
    scopeIdentifiers: scopeIdentifiers,
    definitions: definitions,
    declarationCode: declarationCode,
    sourceMap: $map
  };
};
